<?php

namespace Litecms\Practicecheck\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Practicecheck\Http\Requests\PracticecheckRequest;
use Litecms\Practicecheck\Interfaces\PracticecheckRepositoryInterface;
use Litecms\Practicecheck\Models\Practicecheck;

/**
 * Resource controller class for practicecheck.
 */
class PracticecheckResourceController extends BaseController
{

    /**
     * Initialize practicecheck resource controller.
     *
     * @param type PracticecheckRepositoryInterface $practicecheck
     *
     * @return null
     */
    public function __construct(PracticecheckRepositoryInterface $practicecheck)
    {
        parent::__construct();
        $this->repository = $practicecheck;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Practicecheck\Repositories\Criteria\PracticecheckResourceCriteria::class);
    }

    /**
     * Display a list of practicecheck.
     *
     * @return Response
     */
    public function index(PracticecheckRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Practicecheck\Repositories\Presenter\PracticecheckPresenter::class)
                ->$function();
        }

        $practicechecks = $this->repository->paginate();

        return $this->response->title(trans('practicecheck::practicecheck.names'))
            ->view('practicecheck::practicecheck.index', true)
            ->data(compact('practicechecks'))
            ->output();
    }

    /**
     * Display practicecheck.
     *
     * @param Request $request
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function show(PracticecheckRequest $request, Practicecheck $practicecheck)
    {

        if ($practicecheck->exists) {
            $view = 'practicecheck::practicecheck.show';
        } else {
            $view = 'practicecheck::practicecheck.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('practicecheck::practicecheck.name'))
            ->data(compact('practicecheck'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new practicecheck.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PracticecheckRequest $request)
    {

        $practicecheck = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('practicecheck::practicecheck.name')) 
            ->view('practicecheck::practicecheck.create', true) 
            ->data(compact('practicecheck'))
            ->output();
    }

    /**
     * Create new practicecheck.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PracticecheckRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $practicecheck                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('practicecheck::practicecheck.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('practicecheck/practicecheck/' . $practicecheck->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/practicecheck/practicecheck'))
                ->redirect();
        }

    }

    /**
     * Show practicecheck for editing.
     *
     * @param Request $request
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function edit(PracticecheckRequest $request, Practicecheck $practicecheck)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('practicecheck::practicecheck.name'))
            ->view('practicecheck::practicecheck.edit', true)
            ->data(compact('practicecheck'))
            ->output();
    }

    /**
     * Update the practicecheck.
     *
     * @param Request $request
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function update(PracticecheckRequest $request, Practicecheck $practicecheck)
    {
        try {
            $attributes = $request->all();

            $practicecheck->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('practicecheck::practicecheck.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('practicecheck/practicecheck/' . $practicecheck->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('practicecheck/practicecheck/' . $practicecheck->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the practicecheck.
     *
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function destroy(PracticecheckRequest $request, Practicecheck $practicecheck)
    {
        try {

            $practicecheck->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('practicecheck::practicecheck.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('practicecheck/practicecheck/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('practicecheck/practicecheck/' . $practicecheck->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple practicecheck.
     *
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function delete(PracticecheckRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('practicecheck::practicecheck.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('practicecheck/practicecheck'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/practicecheck/practicecheck'))
                ->redirect();
        }

    }

    /**
     * Restore deleted practicechecks.
     *
     * @param Model   $practicecheck
     *
     * @return Response
     */
    public function restore(PracticecheckRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('practicecheck::practicecheck.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/practicecheck/practicecheck'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/practicecheck/practicecheck/'))
                ->redirect();
        }

    }

}
