<?php

namespace Litecms\Practicecheck\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Practicecheck\Models\Practicecheck;

class PracticecheckPolicy
{

    /**
     * Determine if the given user can view the practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function view(UserPolicy $user, Practicecheck $practicecheck)
    {
        if ($user->canDo('practicecheck.practicecheck.view') && $user->isAdmin()) {
            return true;
        }

        return $practicecheck->user_id == user_id() && $practicecheck->user_type == user_type();
    }

    /**
     * Determine if the given user can create a practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('practicecheck.practicecheck.create');
    }

    /**
     * Determine if the given user can update the given practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function update(UserPolicy $user, Practicecheck $practicecheck)
    {
        if ($user->canDo('practicecheck.practicecheck.edit') && $user->isAdmin()) {
            return true;
        }

        return $practicecheck->user_id == user_id() && $practicecheck->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Practicecheck $practicecheck)
    {
        return $practicecheck->user_id == user_id() && $practicecheck->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Practicecheck $practicecheck)
    {
        if ($user->canDo('practicecheck.practicecheck.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given practicecheck.
     *
     * @param UserPolicy $user
     * @param Practicecheck $practicecheck
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Practicecheck $practicecheck)
    {
        if ($user->canDo('practicecheck.practicecheck.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
